#!/usr/bin/env python

import sys
import wx

from dm.common.constants import dmStatus
from dm.common.exceptions.dmException import DmException
from dm.common.exceptions.configurationError import ConfigurationError
from dm.common.utility.loggingManager import LoggingManager
from dm.common.utility.configurationManager import ConfigurationManager

from experimentsTab import ExperimentsTab
from daqsTab import DaqsTab
from uploadsTab import UploadsTab
 
class DmStationUi(wx.Frame):
    def __init__(self):
        self.__configure()
        self.logger.debug('Starting UI for DM Station: %s' % self.stationName)
        wx.Frame.__init__(self, None, title='DM Station: %s' % self.stationName, size=(900,500))
 
        # Create a panel and notebook (tabs holder)
        p = wx.Panel(self)
        nb = wx.Notebook(p)
 
        # Create the tab windows
        experimentsTab = ExperimentsTab(self.stationName, nb)
        daqsTab = DaqsTab(self.stationName, nb)
        uploadsTab = UploadsTab(self.stationName, nb)
 
        # Add the windows to tabs and name them.
        nb.AddPage(experimentsTab, "Experiments")
        nb.AddPage(daqsTab, "Real Time DAQs")
        nb.AddPage(uploadsTab, "Data Uploads")
 
        # Set noteboook in a sizer to create the layout
        sizer = wx.BoxSizer()
        sizer.Add(nb, 1, wx.EXPAND)
        p.SetSizer(sizer)

    def __configure(self):
        self.logger = LoggingManager.getInstance().getLogger(self.__class__.__name__)
        configManager = ConfigurationManager.getInstance()
        self.stationName = configManager.getInstance().getStationName()
        if not self.stationName:
            raise ConfigurationError('DM_STATION_NAME environment variable is not defined.')
 
if __name__ == "__main__":
    try:
        app = wx.App()
        DmStationUi().Show()
        app.MainLoop()
    except DmException, ex:
        print >>sys.stderr, 'ERROR: %s' % ex
        raise SystemExit(ex.getErrorCode())
    except Exception, ex:
        print >>sys.stderr, '%s' % ex
        raise SystemExit(dmStatus.DM_ERROR)
